@@ -1,3 +1,4 @@
+import logging
 from os.path import basename
 
 from django import forms
@@ -8,6 +9,8 @@ from djangopypi.settings import settings
 from djangopypi.models import Package, Classifier, Release, Distribution
 
 
+log = logging.getLogger('djangopypi.forms')
+
 
 class SimplePackageSearchForm(forms.Form):
     query = forms.CharField(max_length=255)
@@ -31,7 +34,7 @@ class DistributionUploadForm(forms.ModelForm):
                                        filename=content.name)
         
         if not storage.exists(name):
-            print '%s does not exist' % (name,)
+            log.error('%s does not exist', name)
             return content
         
         if settings.DJANGOPYPI_ALLOW_VERSION_OVERWRITE:
